﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Diagnostics;

namespace RadGridViewCommandParameterIssue
{
	/// <summary>
	/// A football club.
	/// </summary>
	public class Club : INotifyPropertyChanged
	{
		public event PropertyChangedEventHandler PropertyChanged;

		private string name;
		private DateTime established;
		private int stadiumCapacity;
		private bool isSelected;

		private RelayCommand<object> clickCommand;

		public bool IsSelected
		{
			get { return this.isSelected; }
			set
			{
				if (value != this.isSelected)
				{
					this.isSelected = value;
					this.OnPropertyChanged("IsSelected");
				}
			}
		}
		public string Name
		{
			get { return this.name; }
			set
			{
				if (value != this.name)
				{
					this.name = value;
					this.OnPropertyChanged("Name");
				}
			}
		}

		public DateTime Established
		{
			get { return this.established; }
			set
			{
				if (value != this.established)
				{
					this.established = value;
					this.OnPropertyChanged("Established");
				}
			}
		}

		public int StadiumCapacity
		{
			get { return this.stadiumCapacity; }
			set
			{
				if (value != this.stadiumCapacity)
				{
					this.stadiumCapacity = value;
					this.OnPropertyChanged("StadiumCapacity");
				}
			}
		}

		public RelayCommand<object> ClickCommand
		{
			get
			{
				if (this.clickCommand == null)
				{
					this.clickCommand = new RelayCommand<object>(this.ClickCommandHandler);
				}
				return this.clickCommand;
			}
		}

		private void ClickCommandHandler(object obj)
		{
			Club club = obj as Club;
			Debug.WriteLine(string.Format("Name -> {0}\nEstablished -> {1}\nStadiumCapacity -> {2}", club.name, club.Established, club.StadiumCapacity));
		}


		public Club()
		{

		}

		public Club(string name, DateTime established, int stadiumCapacity, bool isSelected)
		{
			this.name = name;
			this.established = established;
			this.stadiumCapacity = stadiumCapacity;
			this.isSelected = isSelected;
		}


		protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
		{
			PropertyChangedEventHandler handler = this.PropertyChanged;
			if (handler != null)
			{
				handler(this, args);
			}
		}

		private void OnPropertyChanged(string propertyName)
		{
			this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
		}

		public override string ToString()
		{
			return this.Name;
		}

		public static Dictionary<int, Club> GetClubs()
		{
			Dictionary<int, Club> clubs = new Dictionary<int, Club>();
			Club club;
			for (int i = 0; i < 50; i++)
			{
				club = new Club("Team " + i, new DateTime(1892, 1, 1), i, false);
				clubs.Add(i, club);
			}

			return clubs;
		}
	}
}
